"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CypressEasyNetworkStub = void 0;
const easy_network_stub_1 = require("easy-network-stub");
class CypressEasyNetworkStub extends easy_network_stub_1.EasyNetworkStub {
    /**
     * A class to intercept and stub all calls to a certain api path.
     * @param urlMatch The match for all request urls that should be intercepted.
     * All non-stubbed calls that match this interceptor will throw an error
     */
    constructor(urlMatch) {
        super(urlMatch);
    }
    /**
     * Call this in your beforeEach hook to start using the stub.
     * @returns The cypress chainable to chain to and to have it include itself into an existing chain.
     */
    init() {
        return this.initInternal({
            failer: error => assert.fail(error instanceof Error ? error.message : error),
            interceptor: (baseUrl, handler) => {
                return cy.intercept({ url: baseUrl }, req => {
                    handler({
                        url: req.url,
                        method: req.method,
                        headers: req.headers,
                        destroy: () => req.destroy(),
                        reply: reply => req.reply(reply),
                        body: req.body
                    });
                });
            }
        });
    }
}
exports.CypressEasyNetworkStub = CypressEasyNetworkStub;
//# sourceMappingURL=cypress-easy-network-stub.js.map